#include <algorithm>
#include <array>
#include <cassert>
#include <climits>
#include <cmath>
#include <iomanip>
#include <iostream>
#include <map>
#include <random>
#include <unordered_map>
#include <vector>
#include "circle.h"

static std::vector<std::pair<double, double>> points;
static std::vector<std::tuple<double, double, double>> circles;
static int calls = 0;
static int __Q = 0;
static int __K;
static const int MAX_CALLS = 100000;
static const double MAX_COORD = 5e5;
static const double MAX_RADIUS = 5e5;

void check_value(double val, const char* name) {
    if(std::isnan(val) || std::isinf(val) || std::abs(val) > MAX_COORD) {
        std::cerr << "Invalid " << name << " value: " << val << "\n";
        std::cout << -2 << "\n";
        exit(0);
    }
}

void answer(double cen_x, double cen_y, double radius) {
    calls++;
    if(calls > __K) {
        std::cerr << "Too many answer() calls\n";
        std::cout << -1 << "\n";
        exit(0);
    }

    check_value(cen_x, "x");
    check_value(cen_y, "y");
    check_value(radius, "radius");

    if(radius <= 0) {
        std::cerr << "Invalid radius: " << radius << "\n";
        std::cout << -2 << "\n";
        exit(0);
    }

    circles.push_back({cen_x, cen_y, radius});
}

std::pair<double, double> sample_star() {
    __Q++;
    if(__Q > MAX_CALLS) {
        std::cerr << "Too many sample_star() calls\n";
        std::cout << -3 << "\n";
        exit(0);
    }

    return points[__Q - 1];
}


int main() {
    const int mod = 999142949;
    int hsh = 0;

    int N, K;
    std::cin >> N >> K;

    points.resize(N);
    for(int i = 0; i < N; i++) {
        std::cin >> points[i].first >> points[i].second;
        hsh = (1LL * hsh * (N + 43) + (long long)points[i].second) % mod;
        hsh = (1LL * hsh * (N + 53) + (long long)points[i].first) % mod;
    }

    __K = K;
    solve(K);

    if(circles.size() != K) {
        std::cerr << "Wrong number of circles\n";
        std::cout << -1 << "\n";
        exit(0);
    }

    std::cout << 1 << "\n";
    std::cout << hsh << "\n";
    std::cout << __Q << "\n";
    for(const auto& [cx, cy, r]: circles) {
        std::cout << std::setprecision(9) << std::fixed << cx << " " << cy
                  << " " << r << "\n";
    }

    return 0;
}
